#
# spec file for package python-autoray
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-autoray
Version:        0.6.12
Release:        3.1
Summary:        A lightweight python automatic-array library
License:        Apache-2.0
URL:            https://github.com/jcmgray/autoray
Source:         https://files.pythonhosted.org/packages/source/a/autoray/autoray-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.6}
BuildRequires:  %{python_module dask-array}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module opt-einsum}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Write backend agnostic numeric code compatible with any numpy-ish array library.

%prep
%setup -q -n autoray-%{version}
sed -i -e '/addopts/d' setup.cfg

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# flaky test (failed 2 out of 6 times on x86_64 during preparation for submit)
donttest="(test_linalg_solve and float32-numpy)"
# 32 bit not supported upstream: this one fails because it cannot cast int64 to int32 on 32-bit
[ $(getconf LONG_BIT) -eq 32 ] && donttest="$donttest or (test_take and numpy)"
%pytest -k "not ($donttest)"

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/autoray
%{python_sitelib}/autoray-%{version}.dist-info

%changelog
* Fri Aug 30 2024 Ben Greiner <code@bnavigator.de>
- Unpin numpy 2
- Clean Build Requirements
* Tue Jul  9 2024 Steve Kowalik <steven.kowalik@suse.com>
- Restrict numpy to < 2.
* Thu Jun  6 2024 Dirk Müller <dmueller@suse.com>
- update to 0.6.12:
  * add `torch.indices` and `tensorflow.indices`
- update to 0.6.11:
  * Fix creation functions with builtin `like` kwarg
  * Allow additional keyword arguments in `tensorflow_diag`
- update to 0.6.10:
  * The following functions now inherit default `dtype` and
    possibly `device` (when using torch) when the `like` kwarg is
    an explicit array:
  * `"empty"`
  * `"eye"`
  * `"full"`
  * `"identity"`
  * `"ones"`
  * `"zeros"`
  * fix NumpyMimic special attribute access
  * fix `"diag"` for tensorflow.
* Sat Apr  6 2024 Dirk Müller <dmueller@suse.com>
- update to 0.6.9:
  * `autojit`: fix jax when kwargs are used
  * `autojit`: simplify torch and python compiler
  * torch: alias min/max to amin/amax
* Tue Jan 30 2024 Dirk Müller <dmueller@suse.com>
- update to 0.6.8:
  * Alias jax.scipy
* Fri Nov 10 2023 Dirk Müller <dmueller@suse.com>
- update to 0.6.7:
  * `lazy.einsum`: allow `cotengra` or `opt_einsum` for advanced
    parsing, fall back to basic when neither present
  * add `torch.expand_dims`.
  * **Full Changelog**:
    https://github.com/jcmgray/autoray/compare/v0.6.6...v0.6.7
* Mon Sep 25 2023 jun wang <junguo.wang@suse.com>
- update to 0.6.6
  * autoray.lazy: allow more functions to work on pytrees
  * Fix importlib import error and update tensorflow CI
  * add multi-dispatch for a few more relevant functions
  * change plot_history_functions default style to scatter
  * ensure composed function names are kept
  * add autoray.size
  * added docs
  * autoray.lazy.LazyArray support all fancy indexing
  * add experimental complexity cost tracing
  * fix: matmul shape for lazy by @yangguohao in #16
* Sun Apr 16 2023 Dirk Müller <dmueller@suse.com>
- update to 0.6.3:
  * `autoray.lazy.compute`: allow computing multiple outputs
    simultaneously
  * `autoray.lazy.Function` allow pickling and viewing of
    uncompiled source
  * make sure `shape` and `ndim` work for builtins similarly to
    `numpy.{shape,ndim}`
  * Add: `autoray.lazy.where` function for `LazyArray`
  * Add: `autoray.lazy.take` function for `LazyArray`
  * Add`LazyArray.plot_history_stats` pie charts
  * Add `autoray.shape` and `autoray.ndim` as preferred shape
    functions
  * Add basic support for `aesara`
  * `LazyArray`: fix negative axis reductions
  * fix fancy indexing of `LazyArray` objects
* Thu Jan 26 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.6.0
  * autoray.lazy: Much better tools for inspecting the
    computational graph:
  - LazyArray.show()
  - LazyArray.plot_circuit()
  - LazyArray.plot_history_functions() and variants
  - LazyArray.history_fn_frequencies
  * Global submodule aliases:
  - enables e.g. dispatching do("scipy.linalg.lu", x:
    numpy.ndarray) and cupy.scipy to cupyx.scipy
  * Fix for complex and builtins and newer numpy (#11).
* Sat Jan 14 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.5.3
  * add lazy.diag
  * update infrastructure, including moving from versioneer to
    setuptools_scm
- Release 0.5.1
  * allow Composed.register to be used as a decorator
- Release 0.3.2
  * tweaks to compiler.py
- No relevant release or tag notes for other releases since 0.2.5
- PEP517 build
* Mon Jan 24 2022 Benjamin Greiner <code@bnavigator.de>
- SciPy and dask are optional
- Don't test dask with python310: not supported yet
* Fri Feb 19 2021 andy great <andythe_great@pm.me>
- Update to version 0.2.5.
  * No changelog given.
- Skip python36 because numpy no longer support it.
* Wed Aug 19 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix source url to fetch from github
* Wed Aug 19 2020 Tomáš Chvátal <tchvatal@suse.com>
- Remove not stated dependencies
- Do not run coverage testing
* Tue Aug 18 2020 andy great <andythe_great@pm.me>
- Initial package release.
